---
name: "\U0001F41E Bug report"
about: Report a problem
title: 'Bug: BUG'
labels: ''
assignees: ''

---

## Describe the bug

A clear and concise description of what the bug is.

## Expected behavior

A clear and concise description of what you expected to happen.

## Error log

Add the full error log which is output when the bug occurs.

## Minimum working example

Add a minimal example which can be used to reproduce the bug.

## Additional context

Add any other context about the problem here.
